<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Tobias Blaser, Otavio Huber, Willi Kernen, <contact@gridds.com>, GRiDDS GmbH
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Region Class
 * 
 * @package grds_language_menu
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class Tx_GrdsLanguageMenu_Domain_Model_Region extends Tx_Extbase_DomainObject_AbstractEntity {

	/**
	 * name
	 *
	 * @var string
	 * @validate NotEmpty
	 */
	protected $name;

	/**
	 * flag
	 *
	 * @var string
	 */
	protected $flag;

	/**
	 * abbreviation
	 *
	 * @var string
	 */
	protected $abbreviation;

	/**
	 * languages
	 *
	 * @var Tx_Extbase_Persistence_ObjectStorage<Tx_GrdsLanguageMenu_Domain_Model_Language>
	 */
	protected $languages;

	/**
	 * __construct
	 *
	 * @return void
	 */
	public function __construct() {
		$this->initStorageObjects();
	}

	/**
	 * Initializes all Tx_Extbase_Persistence_ObjectStorage properties.
	 *
	 * @return void
	 */
	protected function initStorageObjects() {
		/**
		 * Do not modify this method!
		 * It will be rewritten on each save in the extension builder
		 * You may modify the constructor of this class instead
		 */
		$this->languages = new Tx_Extbase_Persistence_ObjectStorage();
	}

	/**
	 * Returns the name
	 *
	 * @return string $name
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * Sets the name
	 *
	 * @param string $name
	 * @return void
	 */
	public function setName($name) {
		$this->name = $name;
	}

	/**
	 * Returns the flag
	 *
	 * @return string $flag
	 */
	public function getFlag() {
		return $this->flag;
	}

	/**
	 * Sets the flag
	 *
	 * @param string $flag
	 * @return void
	 */
	public function setFlag($flag) {
		$this->flag = $flag;
	}

	/**
	 * Returns the abbreviation
	 *
	 * @return string $abbreviation
	 */
	public function getAbbreviation() {
		return $this->abbreviation;
	}

	/**
	 * Sets the abbreviation
	 *
	 * @param string $abbreviation
	 * @return void
	 */
	public function setAbbreviation($abbreviation) {
		$this->abbreviation = $abbreviation;
	}

	/**
	 * Adds a Language
	 *
	 * @param Tx_GrdsLanguageMenu_Domain_Model_Language $language
	 * @return void
	 */
	public function addLanguage(Tx_GrdsLanguageMenu_Domain_Model_Language $language) {
		$this->languages->attach($language);
	}

	/**
	 * Removes a Language
	 *
	 * @param Tx_GrdsLanguageMenu_Domain_Model_Language $languageToRemove The Language to be removed
	 * @return void
	 */
	public function removeLanguage(Tx_GrdsLanguageMenu_Domain_Model_Language $languageToRemove) {
		$this->languages->detach($languageToRemove);
	}

	/**
	 * Returns the languages
	 *
	 * @return Tx_Extbase_Persistence_ObjectStorage<Tx_GrdsLanguageMenu_Domain_Model_Language> $languages
	 */
	public function getLanguages() {
		return $this->languages;
	}

	/**
	 * Sets the languages
	 *
	 * @param Tx_Extbase_Persistence_ObjectStorage<Tx_GrdsLanguageMenu_Domain_Model_Language> $languages
	 * @return void
	 */
	public function setLanguages(Tx_Extbase_Persistence_ObjectStorage $languages) {
		$this->languages = $languages;
	}
}
?>